package com.zcloud.zcGbsServicer.command.convertor;

import com.zcloud.zcGbsServicer.domain.model.PumpRoomE;
import com.zcloud.zcGbsServicer.dto.clientobject.PumpRoomCO;
import com.zcloud.zcGbsServicer.dto.clientobject.PumpRoomScreenCO;
import com.zcloud.zcGbsServicer.dto.clientobject.ResourceDeviceCO;
import com.zcloud.zcGbsServicer.persistence.dataobject.PumpRoomDO;
import org.mapstruct.Mapper;

import java.util.List;



/**
* web-app
* @Author makejava
* @Date 2026-01-21 17:22:16
*/
@Mapper(componentModel = "spring")
public interface PumpRoomCoConvertor {
    /**
    * @param pumpRoomDOs
    * @return
    */
    List<PumpRoomCO> converDOsToCOs(List<PumpRoomDO> pumpRoomDOs);

    List<PumpRoomScreenCO> converDOsToScreenCOs(List<PumpRoomDO> pumpRoomDOs);

    List<PumpRoomE> converDOsToE(List<PumpRoomDO> pumpRoomDOs);

    List<PumpRoomCO> converEtoCOs(List<PumpRoomE> pumpRoomE);

    PumpRoomE converDOtoE(PumpRoomDO pumpRoomDO);

    PumpRoomCO converEtoCO(PumpRoomE pumpRoomE);

    PumpRoomScreenCO converDOToScreenCO(PumpRoomDO pumpRoomDO);

    ResourceDeviceCO converEtoCO1(PumpRoomE pumpRoomE);
}

